==> 0.2.8.tar.gz: lib/pages/home/slock/info/DeviceInfo.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:witsystem_core/config/VibrateConfig.dart';
import 'package:witsystem_core/error/NetError.dart';
import 'package:witsystem_core/error/handle/AutoErrorHandle.dart';
import 'package:witsystem_core/pages/witDialog/DialogCenterHintWidget.dart';
import 'package:witsystem_core/pages/witDialog/DialogCenterInputWidget.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:witsystem_device_manage/pages/home/bindRelay/BindRelay.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';
import 'package:witsystem_device_plugin/device/Unlock.dart';
import 'package:witsystem_device_plugin/enity/DeviceSoftwareInfo.dart';

///设备信息

class DeviceInfoWidget extends StatefulWidget {
  final String deviceId;

  const DeviceInfoWidget({Key? key, required this.deviceId}) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _DeviceInfoState();
  }
}

class _DeviceInfoState extends State<DeviceInfoWidget> {
  DeviceSoftwareInfo? deviceSoftwareInfo;

  Map info = {};

  @override
  void initState() {
    super.initState();
    _getDeviceInfo();
  }

  ///获得设备信息
  _getDeviceInfo() async {
    var device = await DeviceManage().device(widget.deviceId);
    info.addAll(device!);
    deviceSoftwareInfo = await DeviceManage()
        .getDeviceSoftwareFunction(widget.deviceId); //获得 设备软件编码解析的信息
    setState(() {});
  }

  ///点击删除
  _delete() {
    DialogCenterHint().show(
      context: context,
      title: S.current.device_deleteDevice,
      content: S.current.device_deleteDeviceHint(info["deviceName"]),
      outSideDismissible: true,
      affirmText: S.of(context).device_delete,
      affirmTextColor: Colors.red,
      onPressed: (bool value) {
        if (value) _affirmDelete();
      },
    );
  }

  ///确认删除
  _affirmDelete() async {
    try {
      EasyLoading.show(status: S.of(context).device_execution);
      await DeviceManage().deleteDevices(widget.deviceId);
      EasyLoading.dismiss();
      EasyLoading.showToast(S.current.device_deleteSuccess);
      Future.delayed(const Duration(milliseconds: 1500), () {
        Navigator.popUntil(context, ModalRoute.withName("deviceIndex"));
      });
    } on PlatformException catch (e) {
      EasyLoading.dismiss();
      var auto = AutoErrorHandle.auto(e);
      EasyLoading.showToast(auto.error);
    }
  }

  ///点击修改名称
  _updateDeviceName() {
    DialogCenterInput().show(
      context: context,
      title: S.current.device_updateDeviceName,
      contentHint: S.current.device_updateDeviceNameHint,
      outSideDismissible: true,
      affirmText: S.of(context).device_revise,
      affirmTextColor: Colors.red,
      onPressed: (bool tag, String text) {
        if (tag) _affirmUpdateDeviceName(text);
      },
    );
  }

  ///确认修改
  _affirmUpdateDeviceName(String newName) async {
    Future.delayed(const Duration(milliseconds: 100), () async {
      try {
        EasyLoading.show(status: S.of(context).device_execution);
        await DeviceManage().updateDeviceName(widget.deviceId, newName);
        EasyLoading.dismiss();
        EasyLoading.showToast(S.current.device_updateSuccess);
        _getDeviceInfo();
      } on PlatformException catch (e) {
        EasyLoading.dismiss();
        var auto = AutoErrorHandle.auto(e);
        EasyLoading.showToast(auto.error);
      }
    });
  }

  ///点击远程开门
  longUnlock() async {
    if (!info["device"]["onLine"]) {
      EasyLoading.showToast(S.current.device_deviceNotOnline);
      return;
    }
    try {
      EasyLoading.show(status: S.current.device_execution);
      await Unlock().longUnlock(widget.deviceId,
          isVibrate: VibrateConfig().unlockVibrate);
      EasyLoading.dismiss();
      EasyLoading.showSuccess(S.current.device_success);
    } on PlatformException catch (e) {
      EasyLoading.dismiss();
      var error = NetError.error(int.parse(e.code));
      EasyLoading.showError(error.error);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
          title: Text(
              S.of(context).device_deviceInfo + "(${info["deviceName"]})")),
      body: info.isNotEmpty
          ? ListView(
              children: [
                ListTile(
                  onTap: _updateDeviceName,
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_deviceName),
                  trailing: Row(
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      Text("${info["deviceName"]}",
                          style: const TextStyle(
                              fontSize: 12, color: Colors.black54)),
                      const Icon(Icons.chevron_right)
                    ],
                  ),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  onTap: () {
                    Navigator.of(context)
                        .push(MaterialPageRoute(builder: (context) {
                      return BindRelayWidget(deviceId: widget.deviceId);
                    })).then((value) {
                      _getDeviceInfo();
                    });
                  },
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_deviceIsOnLine),
                  trailing: Row(
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      Text(
                          " ${info["device"]["onLine"] ? S.of(context).device_deviceOnLine : S.of(context).device_deviceOffLine}",
                          style: TextStyle(
                              fontSize: 12,
                              color: info["device"]["onLine"]
                                  ? Colors.green
                                  : Colors.red)),
                      const Icon(Icons.chevron_right)
                    ],
                  ),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_deviceAddress),
                  trailing: Text("${info["deviceId"]}",
                      style:
                          const TextStyle(fontSize: 12, color: Colors.black54)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_deviceModel),
                  trailing: Text("${info["device"]["model"]}",
                      style:
                          const TextStyle(fontSize: 12, color: Colors.black54)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_deviceVersion),
                  trailing: Text("${info["device"]["version"]}",
                      style:
                          const TextStyle(fontSize: 12, color: Colors.black54)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_authType),
                  trailing: Text("${info["authType"]}",
                      style:
                          const TextStyle(fontSize: 12, color: Colors.black54)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_deviceBattery),
                  trailing: Text("${info["device"]["battery"]}%",
                      style: TextStyle(
                          fontSize: 12,
                          color: info["device"]["battery"] >= 80
                              ? Colors.green
                              : info["device"]["battery"] >= 20
                                  ? Colors.yellow.shade900
                                  : Colors.red)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_passwordNumber),
                  trailing: Text(
                      deviceSoftwareInfo!.passwordSum == 0
                          ? S.of(context).device_nonsupport
                          : "${deviceSoftwareInfo!.passwordSum}",
                      style: TextStyle(
                          fontSize: 12,
                          color: deviceSoftwareInfo!.passwordSum == 0
                              ? Colors.red
                              : Colors.green)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_cardNumber),
                  trailing: Text(
                      deviceSoftwareInfo!.cardSum == 0
                          ? S.of(context).device_nonsupport
                          : "${deviceSoftwareInfo!.cardSum}",
                      style: TextStyle(
                          fontSize: 12,
                          color: deviceSoftwareInfo!.cardSum == 0
                              ? Colors.red
                              : Colors.green)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_markNumber),
                  trailing: Text(
                      deviceSoftwareInfo!.markSum == 0
                          ? S.of(context).device_nonsupport
                          : "${deviceSoftwareInfo!.markSum}",
                      style: TextStyle(
                          fontSize: 12,
                          color: deviceSoftwareInfo!.markSum == 0
                              ? Colors.red
                              : Colors.green)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_faceNumber),
                  trailing: Text(
                      deviceSoftwareInfo!.faceSum == 0
                          ? S.of(context).device_nonsupport
                          : "${deviceSoftwareInfo!.faceSum}",
                      style: TextStyle(
                          fontSize: 12,
                          color: deviceSoftwareInfo!.faceSum == 0
                              ? Colors.red
                              : Colors.green)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_bleConnectNumber),
                  trailing: Text("${deviceSoftwareInfo!.connectionNumber}",
                      style:
                          const TextStyle(fontSize: 12, color: Colors.black54)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  onTap: longUnlock,
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_longUnlock),
                  trailing: const Icon(Icons.chevron_right),
                ),
                const Divider(height: 1, color: Colors.black38),
                Padding(
                  padding: const EdgeInsets.fromLTRB(10, 50, 10, 50),
                  child: MaterialButton(
                      onPressed: _delete,
                      padding: const EdgeInsets.fromLTRB(0, 20, 0, 20),
                      shape: const RoundedRectangleBorder(
                        borderRadius: BorderRadius.all(Radius.circular(10)),
                      ),
                      color: Colors.red,
                      child: Text(S.of(context).device_deleteDevice,
                          style: const TextStyle(color: Colors.white))),
                )
              ],
            )
          : const SizedBox(),
    );
  }
}

==> 0.2.9.tar.gz: lib/pages/home/slock/info/DeviceInfo.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:witsystem_core/config/VibrateConfig.dart';
import 'package:witsystem_core/error/NetError.dart';
import 'package:witsystem_core/error/handle/AutoErrorHandle.dart';
import 'package:witsystem_core/pages/witDialog/DialogCenterHintWidget.dart';
import 'package:witsystem_core/pages/witDialog/DialogCenterInputWidget.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:witsystem_device_manage/pages/home/bindRelay/BindRelay.dart';
import 'package:witsystem_device_manage/pages/home/slock/SlcokHome.dart';
import 'package:witsystem_device_manage/witsystem_device_list_widget.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';
import 'package:witsystem_device_plugin/device/Unlock.dart';
import 'package:witsystem_device_plugin/enity/DeviceSoftwareInfo.dart';

///设备信息

class DeviceInfoWidget extends StatefulWidget {
  final String deviceId;

  const DeviceInfoWidget({Key? key, required this.deviceId}) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _DeviceInfoState();
  }
}

class _DeviceInfoState extends State<DeviceInfoWidget> {
  DeviceSoftwareInfo? deviceSoftwareInfo;

  Map info = {};

  @override
  void initState() {
    super.initState();
    _getDeviceInfo();
  }

  ///获得设备信息
  _getDeviceInfo() async {
    var device = await DeviceManage().device(widget.deviceId);
    info.addAll(device!);
    deviceSoftwareInfo = await DeviceManage()
        .getDeviceSoftwareFunction(widget.deviceId); //获得 设备软件编码解析的信息
    setState(() {});
  }

  ///点击删除
  _delete() {
    DialogCenterHint().show(
      context: context,
      title: S.current.device_deleteDevice,
      content: S.current.device_deleteDeviceHint(info["deviceName"]),
      outSideDismissible: true,
      affirmText: S.of(context).device_delete,
      affirmTextColor: Colors.red,
      onPressed: (bool value) {
        if (value) _affirmDelete();
      },
    );
  }

  ///确认删除
  _affirmDelete() async {
    //ModalRoute.withName("deviceIndex");
    // Navigator.popUntil(context, (Route<dynamic> route) {
    //   return route.isFirst || route.settings.name == "deviceList";
    // });

    try {
      EasyLoading.show(status: S.of(context).device_execution);
      await DeviceManage().deleteDevices(widget.deviceId);
      EasyLoading.dismiss();
      EasyLoading.showToast(S.current.device_deleteSuccess);
      Future.delayed(const Duration(milliseconds: 1500), () {
        Navigator.popUntil(context, (Route<dynamic> route) {
          return (route.isFirst || route.settings.name == "deviceList");
        });
      });
    } on PlatformException catch (e) {
      EasyLoading.dismiss();
      var auto = AutoErrorHandle.auto(e);
      EasyLoading.showToast(auto.error);
    }
  }

  ///点击修改名称
  _updateDeviceName() {
    DialogCenterInput().show(
      context: context,
      title: S.current.device_updateDeviceName,
      contentHint: S.current.device_updateDeviceNameHint,
      outSideDismissible: true,
      affirmText: S.of(context).device_revise,
      affirmTextColor: Colors.red,
      onPressed: (bool tag, String text) {
        if (tag) _affirmUpdateDeviceName(text);
      },
    );
  }

  ///确认修改
  _affirmUpdateDeviceName(String newName) async {
    Future.delayed(const Duration(milliseconds: 100), () async {
      try {
        EasyLoading.show(status: S.of(context).device_execution);
        await DeviceManage().updateDeviceName(widget.deviceId, newName);
        EasyLoading.dismiss();
        EasyLoading.showToast(S.current.device_updateSuccess);
        _getDeviceInfo();
      } on PlatformException catch (e) {
        EasyLoading.dismiss();
        var auto = AutoErrorHandle.auto(e);
        EasyLoading.showToast(auto.error);
      }
    });
  }

  ///点击远程开门
  longUnlock() async {
    if (!info["device"]["onLine"]) {
      EasyLoading.showToast(S.current.device_deviceNotOnline);
      return;
    }
    try {
      EasyLoading.show(status: S.current.device_execution);
      await Unlock().longUnlock(widget.deviceId,
          isVibrate: VibrateConfig().unlockVibrate);
      EasyLoading.dismiss();
      EasyLoading.showSuccess(S.current.device_success);
    } on PlatformException catch (e) {
      EasyLoading.dismiss();
      var error = NetError.error(int.parse(e.code));
      EasyLoading.showError(error.error);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
          title: Text(
              S.of(context).device_deviceInfo + "(${info["deviceName"]})")),
      body: info.isNotEmpty
          ? ListView(
              children: [
                ListTile(
                  onTap: _updateDeviceName,
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_deviceName),
                  trailing: Row(
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      Text("${info["deviceName"]}",
                          style: const TextStyle(
                              fontSize: 12, color: Colors.black54)),
                      const Icon(Icons.chevron_right)
                    ],
                  ),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  onTap: () {
                    Navigator.of(context)
                        .push(MaterialPageRoute(builder: (context) {
                      return BindRelayWidget(deviceId: widget.deviceId);
                    })).then((value) {
                      _getDeviceInfo();
                    });
                  },
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_deviceIsOnLine),
                  trailing: Row(
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      Text(
                          " ${info["device"]["onLine"] ? S.of(context).device_deviceOnLine : S.of(context).device_deviceOffLine}",
                          style: TextStyle(
                              fontSize: 12,
                              color: info["device"]["onLine"]
                                  ? Colors.green
                                  : Colors.red)),
                      const Icon(Icons.chevron_right)
                    ],
                  ),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_deviceAddress),
                  trailing: Text("${info["deviceId"]}",
                      style:
                          const TextStyle(fontSize: 12, color: Colors.black54)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_deviceModel),
                  trailing: Text("${info["device"]["model"]}",
                      style:
                          const TextStyle(fontSize: 12, color: Colors.black54)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_deviceVersion),
                  trailing: Text("${info["device"]["version"]}",
                      style:
                          const TextStyle(fontSize: 12, color: Colors.black54)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_authType),
                  trailing: Text("${info["authType"]}",
                      style:
                          const TextStyle(fontSize: 12, color: Colors.black54)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_deviceBattery),
                  trailing: Text("${info["device"]["battery"]}%",
                      style: TextStyle(
                          fontSize: 12,
                          color: info["device"]["battery"] >= 80
                              ? Colors.green
                              : info["device"]["battery"] >= 20
                                  ? Colors.yellow.shade900
                                  : Colors.red)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_passwordNumber),
                  trailing: Text(
                      deviceSoftwareInfo!.passwordSum == 0
                          ? S.of(context).device_nonsupport
                          : "${deviceSoftwareInfo!.passwordSum}",
                      style: TextStyle(
                          fontSize: 12,
                          color: deviceSoftwareInfo!.passwordSum == 0
                              ? Colors.red
                              : Colors.green)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_cardNumber),
                  trailing: Text(
                      deviceSoftwareInfo!.cardSum == 0
                          ? S.of(context).device_nonsupport
                          : "${deviceSoftwareInfo!.cardSum}",
                      style: TextStyle(
                          fontSize: 12,
                          color: deviceSoftwareInfo!.cardSum == 0
                              ? Colors.red
                              : Colors.green)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_markNumber),
                  trailing: Text(
                      deviceSoftwareInfo!.markSum == 0
                          ? S.of(context).device_nonsupport
                          : "${deviceSoftwareInfo!.markSum}",
                      style: TextStyle(
                          fontSize: 12,
                          color: deviceSoftwareInfo!.markSum == 0
                              ? Colors.red
                              : Colors.green)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_faceNumber),
                  trailing: Text(
                      deviceSoftwareInfo!.faceSum == 0
                          ? S.of(context).device_nonsupport
                          : "${deviceSoftwareInfo!.faceSum}",
                      style: TextStyle(
                          fontSize: 12,
                          color: deviceSoftwareInfo!.faceSum == 0
                              ? Colors.red
                              : Colors.green)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_bleConnectNumber),
                  trailing: Text("${deviceSoftwareInfo!.connectionNumber}",
                      style:
                          const TextStyle(fontSize: 12, color: Colors.black54)),
                ),
                const Divider(height: 1, color: Colors.black38),
                ListTile(
                  onTap: longUnlock,
                  contentPadding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                  title: Text(S.of(context).device_longUnlock),
                  trailing: const Icon(Icons.chevron_right),
                ),
                const Divider(height: 1, color: Colors.black38),
                Padding(
                  padding: const EdgeInsets.fromLTRB(10, 50, 10, 50),
                  child: MaterialButton(
                      onPressed: _delete,
                      padding: const EdgeInsets.fromLTRB(0, 20, 0, 20),
                      shape: const RoundedRectangleBorder(
                        borderRadius: BorderRadius.all(Radius.circular(10)),
                      ),
                      color: Colors.red,
                      child: Text(S.of(context).device_deleteDevice,
                          style: const TextStyle(color: Colors.white))),
                )
              ],
            )
          : const SizedBox(),
    );
  }
}
